@@ -12,7 +12,7 @@ from .i18n import _
 RUNNING_AS_ROOT = os.geteuid() == 0
 
 
-VERSION = '1.6.9.1-dev'
+VERSION = '1.6.10-dev'
 
 _USER_CACHE_HOME = os.environ.get(
     "XDG_CACHE_HOME",
@@ -266,6 +266,11 @@ def write_config(config: configparser.ConfigParser = None) -> None:
             config.write(configfile)
 
 
+def str_to_bool(value: str) -> bool:
+    # pylint:disable=protected-access
+    return configparser.RawConfigParser()._convert_to_boolean(value)  # type: ignore[attr-defined]
+
+
 class PikaurConfigItem:
 
     def __init__(self, section: configparser.SectionProxy, key: str) -> None:
@@ -274,10 +279,9 @@ class PikaurConfigItem:
         self.value = self.section.get(key)
 
     def get_bool(self) -> bool:
-        # pylint:disable=protected-access
         if get_key_type(self.section.name, self.key) != 'bool':
             raise TypeError(f"{self.key} is not 'bool'")
-        return configparser.RawConfigParser()._convert_to_boolean(self.value)  # type: ignore
+        return str_to_bool(self.value)
 
     def get_int(self) -> int:
         if get_key_type(self.section.name, self.key) != 'int':
